# bespokelabs
No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 0.0.1
- Package version: 0.0.1
- Generator version: 7.7.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.7+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/bespokelabsai/bespokelabs-python-client.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/bespokelabsai/bespokelabs-python-client.git`)

Then import the package:
```python
import bespokelabs
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import bespokelabs
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import bespokelabs
from bespokelabs.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost
# See configuration.py for a list of all supported configuration parameters.
configuration = bespokelabs.Configuration(
    host = "http://localhost"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: APIKeyHeader
configuration.api_key['APIKeyHeader'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['APIKeyHeader'] = 'Bearer'


# Enter a context with an instance of the API client
with bespokelabs.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = bespokelabs.DefaultApi(api_client)
    fact_check_request = bespokelabs.FactCheckRequest() # FactCheckRequest | 

    try:
        # Factcheck
        api_response = api_instance.factcheck_v0_argus_factcheck_post(fact_check_request)
        print("The response of DefaultApi->factcheck_v0_argus_factcheck_post:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling DefaultApi->factcheck_v0_argus_factcheck_post: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DefaultApi* | [**factcheck_v0_argus_factcheck_post**](docs/DefaultApi.md#factcheck_v0_argus_factcheck_post) | **POST** /v0/argus/factcheck | Factcheck
*DefaultApi* | [**synthetic_data_download_v0_synthetic_data_download_session_id_post**](docs/DefaultApi.md#synthetic_data_download_v0_synthetic_data_download_session_id_post) | **POST** /v0/synthetic_data/download/{session_id} | Synthetic Data Download
*DefaultApi* | [**synthetic_data_generate_v0_synthetic_data_generate_post**](docs/DefaultApi.md#synthetic_data_generate_v0_synthetic_data_generate_post) | **POST** /v0/synthetic_data/generate | Synthetic Data Generate


## Documentation For Models

 - [Example](docs/Example.md)
 - [FactCheckRequest](docs/FactCheckRequest.md)
 - [FactCheckResponse](docs/FactCheckResponse.md)
 - [HTTPValidationError](docs/HTTPValidationError.md)
 - [LLM](docs/LLM.md)
 - [QAC](docs/QAC.md)
 - [SyntheticDataDownloadResponse](docs/SyntheticDataDownloadResponse.md)
 - [SyntheticDataGenerateResponse](docs/SyntheticDataGenerateResponse.md)
 - [SyntheticDataGenerationState](docs/SyntheticDataGenerationState.md)
 - [ValidationError](docs/ValidationError.md)
 - [ValidationErrorLocInner](docs/ValidationErrorLocInner.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="APIKeyHeader"></a>
### APIKeyHeader

- **Type**: API key
- **API key parameter name**: api_key
- **Location**: HTTP header


## Author

company@bespokelabs.ai


